@@ -192,6 +192,89 @@ static Bcp47ToOOoMapping const bcpToOOoMapping[] = {
 	{"vro", "vro", "EE"},
 	{"xh", "xh", "ZA"},
 	{"yrk", "yrk", "RU"},
+// Added a new block of language codes - should be sorted and merged with the
+// rest when accepted.
+	{"an",	"an",	"ES"},
+	{"as",	"as",	"IN"},
+	{"as-BT",	"as",	"BT"},
+	{"ast",	"ast",	"ES"},
+	{"av",	"av",	"RU"},
+	{"av-AZ",	"av",	"AZ"},
+	{"av-GE",	"av",	"GE"},
+	{"av-KZ",	"av",	"KZ"},
+	{"azj",	"azj",	"AZ"},
+	{"azj-RU",	"azj",	"RU"},
+	{"bak",	"bak",	"RU"},
+	{"bak-KZ",	"bak",	"KZ"},
+	{"be",	"be",	"BY"},
+	{"bg",	"bg",	"BG"},
+	{"bla",	"bla",	"CA"},
+	{"bla-US",	"bla",	"US"},
+	{"br",	"br",	"FR"},
+	{"bxr",	"bxr",	"RU"},
+	{"ce",	"ce",	"RU"},
+	{"ceb",	"ceb",	"PH"},
+	{"chp",	"chp",	"CA"},
+	{"ciw",	"ciw",	"US"},
+	{"cos",	"cos",	"FR"},
+	{"crk",	"crk",	"CA"},
+	{"crk-US",	"crk",	"US"},
+	{"dsb",	"dsb",	"DE"},
+	{"eve",	"eve",	"RU"},
+	{"evn",	"evn",	"CN"},
+	{"evn-RU",	"evn",	"RU"},
+	{"fkv",	"fkv",	"NO"},
+	{"fry",	"fry",	"NL"},
+	{"glk",	"glk",	"IR"},
+	{"grn",	"grn",	"PY"},
+	{"guc",	"guc",	"CO"},
+	{"guc-VE",	"guc",	"VE"},
+	{"gv",	"gv",	"IM"},
+	{"hdn",	"hdn",	"CA"},
+	{"hdn-US",	"hdn",	"US"},
+	{"hsb",	"hsb",	"DE"},
+	{"hy",	"hy",	"AM"},
+	{"ik",	"ik",	"US"},
+	{"izh",	"izh",	"RU"},
+	{"kaa",	"kaa",	"UZ"},
+	{"kaa-RU",	"kaa",	"RU"},
+	{"kaz",	"kaz",	"KZ"},
+	{"khk",	"khk",	"MN"},
+	{"khk-KG",	"khk",	"KG"},
+	{"khk-RU",	"khk",	"RU"},
+	{"khk-CN",	"khk",	"CN"},
+	{"kw",	"kw",	"UK"},
+	{"ltz",	"ltz",	"LU"},
+	{"ml",	"ml",	"IN"},
+	{"mr",	"mr",	"IN"},
+	{"mt",	"mt",	"MT"},
+	{"ndl",	"ndl",	"CD"},
+	{"quz",	"quz",	"PE"},
+	{"qve",	"qve",	"PE"},
+	{"rup",	"rup",	"MK"},
+	{"rup-GR",	"rup",	"GR"},
+	{"rup-RO",	"rup",	"RO"},
+	{"sc",	"sc",	"IT"},
+	{"sel",	"sel",	"RU"},
+	{"si",	"si",	"LK"},
+	{"sje",	"sje",	"SE"},
+	{"so",	"so",	"SO"},
+	{"sq",	"sq",	"AL"},
+	{"sto",	"sto",	"CA"},
+	{"te",	"te",	"IN"},
+	{"tg",	"tg",	"TJ"},
+	{"tg-UZ",	"tg",	"UZ"},
+	{"tl",	"tl",	"PH"},
+	{"tk",	"tk",	"TM"},
+	{"tku",	"tku",	"MX"},
+	{"tus",	"tus",	"CA"},
+	{"tyv",	"tyv",	"RU"},
+	{"ur",	"ur",	"PK"},
+	{"uz",	"uz",	"UZ"},
+	{"uz-KG",	"uz",	"KG"},
+	{"zu",	"zu",	"ZA"},
+	{"zu-LS",	"zu",	"LS"},
+	{"zu-SZ",	"zu",	"SZ"},
 	{0, 0, 0}
 };
 
