@@ -35,8 +35,7 @@ extern "C" SAL_DLLPUBLIC_EXPORT void SAL_CALL
 	*ppEnvTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME ":unsafe";
 } 
 
-Reference<XInterface> SAL_CALL regSettingsCreate(const Reference<XComponentContext> & context)
-	SAL_THROW((Exception)) {
+Reference<XInterface> SAL_CALL regSettingsCreate(const Reference<XComponentContext> & context) {
 	return static_cast< ::cppu::OWeakObject * >(new SettingsEventHandler(context));
 }
 
@@ -49,12 +48,10 @@ static ::cppu::ImplementationEntry const regEntries[] = {
 	  &Hyphenator::getImplementationName_static,
 	  &Hyphenator::getSupportedServiceNames_static,
 	  &::cppu::createSingleComponentFactory, 0, 0 },
-#ifndef DISABLE_GRAMMAR_CHECKER
 	{ &GrammarChecker::get,
 	  &GrammarChecker::getImplementationName_static,
 	  &GrammarChecker::getSupportedServiceNames_static,
 	  &::cppu::createSingleComponentFactory, 0, 0 },
-#endif
 	{ &regSettingsCreate,
 	  &SettingsEventHandler::getImplementationName_static,
 	  &SettingsEventHandler::getSupportedServiceNames_static,
@@ -62,11 +59,6 @@ static ::cppu::ImplementationEntry const regEntries[] = {
 	{ 0, 0, 0, 0, 0, 0 }
 };
 
-extern "C" SAL_DLLPUBLIC_EXPORT sal_Bool SAL_CALL component_writeInfo(void * serviceManager, void * registryKey) {
-	VOIKKO_DEBUG("component_writeInfo");
-	return ::cppu::component_writeInfoHelper(serviceManager, registryKey, regEntries);
-}
-
 extern "C" SAL_DLLPUBLIC_EXPORT void * SAL_CALL
 	component_getFactory(const char * implName, void * serviceManager, void * registryKey) {
 	VOIKKO_DEBUG("component_getFactory");
